Changelog
---------

0.2.11 (2018-06-22)
~~~~~~~~~~~~~~~~~~~~~

- Fixes conflict error.
  [href]

0.2.10 (2018-06-22)
~~~~~~~~~~~~~~~~~~~~~

- Always enables the search widget for directories.
  [href]

0.2.9 (2018-06-15)
~~~~~~~~~~~~~~~~~~~~~

- Fixes overzealous bullet point replacements.
  [href]

0.2.8 (2018-06-14)
~~~~~~~~~~~~~~~~~~~~~

- Small design changes.
  [href]

0.2.7 (2018-06-13)
~~~~~~~~~~~~~~~~~~~~~

- Adjusts directory panel styles.
  [href]

- Resets the whole directory if the reset search button is clicked.
  [href]

- Sorts search results in order of importance.
  [href]

- Shows a clear button in the search box.
  [href]

- Limits hover link javascript to .with-thumbnails.
  [href]

0.2.6 (2018-06-12)
~~~~~~~~~~~~~~~~~~~~~

- Floats images in directories to the right.
  [href]

0.2.5 (2018-06-12)
~~~~~~~~~~~~~~~~~~~~~

- Decreases fuzziness of search results.
  [href]

- Customizes the display of directory entries with thumbnails.
  [href]

0.2.4 (2018-06-11)
~~~~~~~~~~~~~~~~~~~~~

- Ensures separation of Winterthur maps from org.
  [href]

0.2.3 (2018-06-11)
~~~~~~~~~~~~~~~~~~~~~

- Fixes non-https url for Winterthur map.
  [href]

0.2.2 (2018-06-11)
~~~~~~~~~~~~~~~~~~~~~

- Switches global map to the Winterthur custom one.
  [href]

0.2.1 (2018-06-05)
~~~~~~~~~~~~~~~~~~~~~

- Adds a back-link to the directory entry views inside iframes.
  [href]

- Shows a bullet instead of a checkmark in the directory choices.
  [href]

0.2.0 (2018-05-23)
~~~~~~~~~~~~~~~~~~~~~

- Adjusts the style to be closer to the styleguide.
  [href]

0.1.8 (2018-04-30)
~~~~~~~~~~~~~~~~~~~~~

- Adds compatibility with latest onegov.core release.
  [href]

0.1.7 (2018-04-26)
~~~~~~~~~~~~~~~~~~~~~

- Fixes external links not working on IE 11.
  [href]

0.1.6 (2018-03-28)
~~~~~~~~~~~~~~~~~~~~~

- Scrolls to top whenever we load the iframe.
  [href]

0.1.5 (2018-03-23)
~~~~~~~~~~~~~~~~~~~~~

- Fixes streetnames getting wrapped.
  [href]

0.1.4 (2018-03-20)
~~~~~~~~~~~~~~~~~~~~~

- Adjusts framed style.
  [href]

- Discards completely irrevant search results.
  [href]

- Adds support for streets without addresses.
  [href]

0.1.3 (2018-03-08)
~~~~~~~~~~~~~~~~~~~~~

- Fixes iframe height being calculated incorrectly.
  [href]

0.1.2 (2018-03-01)
~~~~~~~~~~~~~~~~~~~~~

- Applies Winterthur's CD to the framed version.
  [href]

0.1.1 (2018-02-06)
~~~~~~~~~~~~~~~~~~~~~

- Adds a frame-ancestors whitelist.
  [href]

0.1.0 (2018-01-31)
~~~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [href]

